#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/21 05:56
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
from argparse import ArgumentParser
import sys

from PIL import Image


class Command:
    def __init__(self):
        pass

    def run_from_argv(self, argv):
        self.parse_args(argv)
        source = self.args['source']
        target = self.args['target']
        if 'jpg' in target.lower():
            Image.open(source).convert('RGB').save(target)
        else:
            Image.open(source).convert('RGBA').save(target)


    def parse_args(self, args):
        if sys.version < '3.9':
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助')
        else:
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助', exit_on_error=False)
        parser.add_argument('source', nargs='?', type=str, help='需要转换的源文件名')
        parser.add_argument('target', type=str, nargs='?', help='要转换成的目标文件名')

        self.args = vars(parser.parse_args(args))


#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/20 05:59
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
from argparse import ArgumentParser
import os
import sys


class Command:
    def __init__(self):
        pass

    def run_from_argv(self, argv):
        self.parse_args(argv)
        if self.args['file_or_dir'] is None:
            raise ValueError('请指定要加密的文件或路径')
        if not os.path.exists(self.args['file_or_dir']):
            raise ValueError(f'{self.args["file_or_dir"]}不存在')

        if os.path.isfile(self.args['file_or_dir']):
            self.encrypt(self.args['file_or_dir'])
        else:
            for r, d, f in os.walk(self.args['file_or_dir']):
                for file in f:
                    self.encrypt(os.path.join(r, file))

    def parse_args(self, args):
        if sys.version < '3.9':
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助')
        else:
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助', exit_on_error=False)
        parser.add_argument('file_or_dir', nargs='?', type=str, help='路径，或需要加密的文件')
        parser.add_argument('--number', type=int, default=10, help='加密用字节数')

        self.args = vars(parser.parse_args(args))

    def encrypt(self, file):
        with open(file, 'rb+') as f:
            first = f.read(self.args['number'])
            f.seek(0-self.args['number'], 2)
            last = f.read()
            f.seek(0)
            f.write(last)
            f.seek(0-self.args['number'], 2)
            f.write(first)
        print(f'处理文件{file}完成')



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/20 03:38
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
from .core import TestProgram


def tools():
    TestProgram().execute()



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/20 06:01
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
from argparse import ArgumentParser, HelpFormatter


class CommandError(Exception):
    """
    Exception class indicating a problem while executing a management
    command.

    If this exception is raised during the execution of a management
    command, it will be caught and turned into a nicely-printed error
    message to the appropriate output stream (i.e., stderr); as a
    result, raising this exception (with a sensible description of the
    error) is the preferred way to indicate that something has gone
    wrong in the execution of a command.
    """

    def __init__(self, *args, returncode=1, **kwargs):
        self.returncode = returncode
        super().__init__(*args, **kwargs)


class CommandParser(ArgumentParser):
    """
    Customized ArgumentParser class to improve some error messages and prevent
    SystemExit in several occasions, as SystemExit is unacceptable when a
    command is called programmatically.
    """

    def __init__(
        self, *, missing_args_message=None, called_from_command_line=None, **kwargs
    ):
        self.missing_args_message = missing_args_message
        self.called_from_command_line = called_from_command_line
        super().__init__(**kwargs)

    def parse_args(self, args=None, namespace=None):
        # Catch missing argument for a better error message
        if self.missing_args_message and not (
            args or any(not arg.startswith("-") for arg in args)
        ):
            self.error(self.missing_args_message)
        return super().parse_args(args, namespace)

    def error(self, message):
        if self.called_from_command_line:
            super().error(message)
        else:
            raise CommandError("Error: %s" % message)


#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/20 04:25
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
import os
import sys
from argparse import ArgumentParser


class TestProgram:
    def __init__(self, args=None):
        self.args = args or sys.argv[1:]

    def parse_args(self, args):
        if sys.version < '3.9':
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助')
        else:
            parser = ArgumentParser(description='xinlan-tools 命令行参数帮助', exit_on_error=False)
        parser.add_argument('file_or_dir', nargs='?', type=str, help='路径，或需要加密的文件')
        parser.add_argument('--number', type=int, default=10, help='加密用字节数')
        if args:
            self.args = vars(parser.parse_args(args))
        else:
            self.args = vars(parser.parse_args())

    def fetch_command(self, subcommand):
        if subcommand == 'encrypt':
            from .commands.encrypt import Command
            return Command()
        elif subcommand == 'convert':
            from .commands.convert import Command
            return Command()

    def execute(self):
        try:
            subcommand = self.args[0]
        except IndexError:
            subcommand = 'help'

        self.fetch_command(subcommand).run_from_argv(self.args[1:])


if __name__ == '__main__':
    TestProgram().execute()